
clear all

fimage = '..\images\VH_Lund-CIRP.png';
flist{1} = '..\simulations\implicit\Lund-CIRP\L0p5\';
flist{2} = '..\simulations\implicit\Lund-CIRP\L0p7\';
flist{3} = '..\simulations\implicit\Lund-CIRP\L1p0\';
flist{4} = '..\simulations\implicit\Lund-CIRP\L2p0\';
fleg = {'Initial Bed','Measured','\itL_t\rm = 0.5'...
    '\itL_t\rm = 0.7','\itL_t\rm = 1.0','\itL_t\rm = 2.0'};

% fimage = '..\images\VH_Van_Rijn.png';
% flist{1} = '..\simulations\implicit\Van_Rijn\L0p7\';
% flist{1} = '..\simulations\implicit\Van_Rijn\L2p0\';
% flist{2} = '..\simulations\implicit\Van_Rijn\L5p0\';
% flist{3} = '..\simulations\implicit\Van_Rijn\L10p0\';
% fleg = {'Initial Bed','Measured','\itL_t\rm = 0.7'...
%     '\itL_t\rm = 2.0','\itL_t\rm = 5.0'};

% fimage = '..\images\VH_Soulsby.png';
% flist{1} = '..\simulations\implicit\Soulsby\L0p7\';
% flist{2} = '..\simulations\implicit\Soulsby\L1p0\';
% flist{3} = '..\simulations\implicit\Soulsby\L2p0\';
% flist{4} = '..\simulations\implicit\Soulsby\L5p0\';
% fleg = {'Initial Bed','Measured','\itL_t\rm = 0.7'...
%     '\itL_t\rm = 2.0','\itL_t\rm = 5.0'};

%Measurements
hm0 = load('..\data\bed_initial.txt');
hmn = load('..\data\bed_23p5hr.txt');

%Grid
info = hdf5info([flist{1},'Flow_VH_grid.h5']);
s = info.GroupHierarchy.Groups;
nx = s.Attributes(7).Value;
ny = s.Attributes(8).Value;
origin = s.Attributes(6).Value;
xg = hdf5read(s.Datasets(1));
xg = xg + origin(1) - 0.5*(xg(2)-xg(1));

figure('position',[347   288   591   245],'PaperPositionMode','auto')
plot(hm0(:,1),hm0(:,2),'--k','linewidth',2)
hold on
% plot(xg,h0(2,:),'.-k','linewidth',2)
hh = plot(hmn(:,1),hmn(:,2),'dr','markerfacecolor','r');
set(gca,'ydir','reverse','xlim',[13 ,24],...
    'YMinorTick','On','XMinorTick','On')
xlabel('Distance, m')
ylabel('Depth, m')

% c = {'b','g','r','c','m'};
c = {'r','g','c','b','m'};
c = {'m','g','b','c','r'};
c = {'c','b','g','m','r'};
% c = {'b','g','m'};

%Initialize goodness of fit statistics
bss = zeros(length(flist),1);
rmse = bss; nrmse = bss; nmae = bss;
R2 = bss; bias = bss;

for i=1:length(flist)
    %Solution
    sol = readcmsh5([flist{i},'Flow_VH_sol.h5']);
    h0 = reshape(double(sol.Depth.Values(:,1)),nx,ny)';
    hn = reshape(double(sol.Depth.Values(:,end)),nx,ny)';
    t = sol.Depth.Times(end);
    
    %Upstream data
    u = reshape(double(sol.Current_Velocity.Values(1,:,end)),nx,ny)';
    ul = u(1,2); %left boundary (upstream)
    rs = reshape(double(sol.Fraction_Suspended.Values(:,end)),nx,ny)';
    qt = reshape(double(sol.Total_Sediment_Transport.Values(1,:,2)),nx,ny)';
    qsl = rs(1,2)*qt(1,2)*2650; %left boundary (upstream)
    Hs = reshape(double(sol.Wave_Height.Values(:,end)),nx,ny)';
    Hsl = Hs(1,2);
    
    disp('---- Upstream conditions -----')
    disp(['Current= ',num2str(ul),' m/s']) %measured 0.245 m/s
    disp(['Depth= ',num2str(h0(1)),' m'])
    disp(['Suspended transport= ',num2str(qsl),' kg/m/s']) %measured 0.022 kg/m/s
    disp(['Sig. Wave Height= ',num2str(Hsl),' m']) %measured 0.105 m
    
    %Statistics
    hi = interp1(xg,hn(2,:),hmn(:,1));
    ind=isfinite(hi);
    ym = hmn(ind,2); yc = hi(ind); y0 = hm0(ind,2);
    bss(i) = 1 - mean((ym-yc).^2)/mean((ym-y0).^2);
    nrmse(i) = sqrt(mean((ym-yc).^2))/(max(ym)-min(ym));
    nmae(i) = mean(abs(ym-yc))/(max(ym)-min(ym));
    val = corrcoef(ym,yc);
    R2(i) = val(2,1)^2;
    bias(i) = mean(yc-ym);
    
    %Plotting
    plot(xg,hn(2,:),'-','linewidth',2,'color',c{i})
end

disp('--- Goodness of fit statistics  ---')
disp(' BSS    NRMSE    NMAE     R^2   Bias')
for i=1:length(flist)
    fprintf(1,'%6.3f,%7.4f,%7.4f,%7.3f,%7.4f\n',...
        bss(i),nrmse(i),nmae(i),R2(i),bias(i));    
end

legend(fleg,0)
bringtofront(hh)
return

saveas(gcf,fimage)

return
plot(hmn(ind,1),a,'k',hmn(ind,1),b,'r',hmn(ind,1),c,'b')

return
figure
plot(xg,rs(2,:).*qt(2,:)*2650,'.')

